API Reference
=============

Client
------

.. automodule:: pyramid_es
    :members:


.. automodule:: pyramid_es.client
    :members:


Model Mixin
-----------

.. automodule:: pyramid_es.mixin
    :members:


Queries
-------


.. automodule:: pyramid_es.query
    :members:


.. automodule:: pyramid_es.result
    :members:
